from typing import Any, Type, Union
from pydantic import BaseModel
from bs4 import BeautifulSoup

default_model = "gpt-4o-mini-2024-07-18"

def extract_json_fields(content: Union[str, BeautifulSoup], PydanticModel: Type[BaseModel], model: str = default_model) -> dict[str, Any]: ...


from loguru import logger

from perse.perse import reduce_html_content

with open("tests/input.html", "r") as f:
    content = f.read()

logger.info(f"Before: {len(content)}")

exclude_tags = {"script", "style", "svg", "iframe"}
reduced = reduce_html_content(content, exclude_tags)
logger.info(f"After: {len(reduced)}: {reduced}")